@@ -250,7 +250,7 @@ async_update (GnomeVFSAsyncHandle *handle, GnomeVFSXferProgressInfo *info, gpoin
 		return GNOME_VFS_XFER_ERROR_ACTION_ABORT;
 	}
 
-	if (info->bytes_total) {
+	if (info->bytes_total && info->phase == GNOME_VFS_XFER_PHASE_COPYING) {
 		char *text_count;
 		if (info->file_index>0)
 			count++;
@@ -930,7 +930,7 @@ load_bugzillas (void)
 	d(g_list_foreach (druid_data.dldests, (GFunc)p_string, NULL));
 }
 
-#define ALL_APPLICATIONS_URI "applications-all-users:///"
+#define ALL_APPLICATIONS_URI "all-applications:///"
 #define APPLET_REQUIREMENTS \
 	"has_all (repo_ids, ['IDL:Bonobo/Control:1.0'," \
 	"		     'IDL:GNOME/Vertigo/PanelAppletShell:1.0']) && " \
@@ -1217,7 +1217,9 @@ add_product (gpointer key, BugzillaProduct *p, GtkListStore *store)
 static void
 add_products (gpointer key, BugzillaBTS *bts, GtkListStore *store)
 {
-	g_hash_table_foreach (bts->products, (GHFunc)add_product, store);
+	if (bts->products != NULL) {
+		g_hash_table_foreach (bts->products, (GHFunc)add_product, store);
+	}
 }
 
 static void
