@@ -735,7 +735,7 @@ on_druid_next_clicked (GtkWidget *w, gpointer data)
 	case STATE_PRODUCT:
 	{
 		BugzillaProduct *product = NULL;
-		BugzillaApplication *application;
+		BugzillaApplication *application = NULL;
 		/* check that the package is ok */
 		if (GTK_TOGGLE_BUTTON (GET_WIDGET ("no-product-toggle"))->active) {
 			static gboolean dialog_shown = FALSE;
@@ -828,7 +828,7 @@ on_druid_next_clicked (GtkWidget *w, gpointer data)
 			buddy_set_text ("email-to-entry", druid_data.product->bts->email);
 		}
 		
-		if (application->component) {
+		if (application && application->component) {
 			select_component_row (application->component);
 		}
 		break;
